==> prisma-relay-cursor-connection-1.1.0.tgz: package/tests/fixtures.ts <==
import { ProfileCreateInput, TodoCreateInput, UserCreateInput } from '@prisma/client'

export const TODO_FIXTURES: TodoCreateInput[] = [
  { id: 'id_01', text: 'veritatis molestias qui', isCompleted: false },
  { id: 'id_02', text: 'occaecati a dolor', isCompleted: false },
  { id: 'id_03', text: 'ut enim quia', isCompleted: false },
  { id: 'id_04', text: 'ipsam ipsam corrupti', isCompleted: true },
  { id: 'id_05', text: 'voluptatem sint ipsam', isCompleted: true },
  { id: 'id_06', text: 'ut sunt consequuntur', isCompleted: true },
  { id: 'id_07', text: 'accusamus aut labore', isCompleted: false },
  { id: 'id_08', text: 'et quo quia', isCompleted: true },
  { id: 'id_09', text: 'accusantium a excepturi', isCompleted: true },
  { id: 'id_10', text: 'deserunt rerum occaecati', isCompleted: true },
  { id: 'id_11', text: 'unde et quasi', isCompleted: false },
  { id: 'id_12', text: 'et autem sapiente', isCompleted: false },
  { id: 'id_13', text: 'deleniti fuga et', isCompleted: false },
  { id: 'id_14', text: 'ea molestiae similique', isCompleted: true },
  { id: 'id_15', text: 'doloribus ea aut', isCompleted: false },
  { id: 'id_16', text: 'ut molestias veniam', isCompleted: true },
  { id: 'id_17', text: 'a placeat aperiam', isCompleted: true },
  { id: 'id_18', text: 'quos rerum aut', isCompleted: true },
  { id: 'id_19', text: 'ullam a voluptatem', isCompleted: false },
  { id: 'id_20', text: 'dolorum deserunt quis', isCompleted: true },
]

export const USER_FIXTURES: UserCreateInput[] = [
  { id: 1, email: 'user1@email.com' },
  { id: 2, email: 'user2@email.com' },
  { id: 3, email: 'user3@email.com' },
  { id: 4, email: 'user4@email.com' },
  { id: 5, email: 'user5@email.com' },
  { id: 6, email: 'user6@email.com' },
  { id: 7, email: 'user7@email.com' },
  { id: 8, email: 'user8@email.com' },
  { id: 9, email: 'user9@email.com' },
  { id: 10, email: 'user10@email.com' },
  { id: 11, email: 'user11@email.com' },
  { id: 12, email: 'user12@email.com' },
  { id: 13, email: 'user13@email.com' },
  { id: 14, email: 'user14@email.com' },
  { id: 15, email: 'user15@email.com' },
  { id: 16, email: 'user16@email.com' },
  { id: 17, email: 'user17@email.com' },
  { id: 18, email: 'user18@email.com' },
  { id: 19, email: 'user19@email.com' },
  { id: 20, email: 'user20@email.com' },
]

export const PROFILE_FIXTURES: ProfileCreateInput[] = [
  { firstname: 'foo1', lastname: 'bar1' },
  { firstname: 'foo2', lastname: 'bar1' },
  { firstname: 'foo3', lastname: 'bar1' },
  { firstname: 'foo4', lastname: 'bar1' },
  { firstname: 'foo5', lastname: 'bar1' },
  { firstname: 'foo6', lastname: 'bar1' },
  { firstname: 'foo7', lastname: 'bar1' },
  { firstname: 'foo8', lastname: 'bar1' },
  { firstname: 'foo9', lastname: 'bar1' },
  { firstname: 'foo10', lastname: 'bar1' },
  { firstname: 'foo11', lastname: 'bar1' },
  { firstname: 'foo12', lastname: 'bar1' },
  { firstname: 'foo13', lastname: 'bar1' },
  { firstname: 'foo14', lastname: 'bar1' },
  { firstname: 'foo15', lastname: 'bar1' },
  { firstname: 'foo16', lastname: 'bar1' },
  { firstname: 'foo17', lastname: 'bar1' },
  { firstname: 'foo18', lastname: 'bar1' },
  { firstname: 'foo19', lastname: 'bar1' },
  { firstname: 'foo20', lastname: 'bar1' },
]

==> prisma-relay-cursor-connection-3.1.1.tgz: package/tests/fixtures.ts <==
import { Prisma } from '@prisma/client'

export const TODO_FIXTURES: Prisma.TodoCreateInput[] = [
  { id: 'id_01', text: 'veritatis molestias qui', isCompleted: false },
  { id: 'id_02', text: 'occaecati a dolor', isCompleted: false },
  { id: 'id_03', text: 'ut enim quia', isCompleted: false },
  { id: 'id_04', text: 'ipsam ipsam corrupti', isCompleted: true },
  { id: 'id_05', text: 'voluptatem sint ipsam', isCompleted: true },
  { id: 'id_06', text: 'ut sunt consequuntur', isCompleted: true },
  { id: 'id_07', text: 'accusamus aut labore', isCompleted: false },
  { id: 'id_08', text: 'et quo quia', isCompleted: true },
  { id: 'id_09', text: 'accusantium a excepturi', isCompleted: true },
  { id: 'id_10', text: 'deserunt rerum occaecati', isCompleted: true },
  { id: 'id_11', text: 'unde et quasi', isCompleted: false },
  { id: 'id_12', text: 'et autem sapiente', isCompleted: false },
  { id: 'id_13', text: 'deleniti fuga et', isCompleted: false },
  { id: 'id_14', text: 'ea molestiae similique', isCompleted: true },
  { id: 'id_15', text: 'doloribus ea aut', isCompleted: false },
  { id: 'id_16', text: 'ut molestias veniam', isCompleted: true },
  { id: 'id_17', text: 'a placeat aperiam', isCompleted: true },
  { id: 'id_18', text: 'quos rerum aut', isCompleted: true },
  { id: 'id_19', text: 'ullam a voluptatem', isCompleted: false },
  { id: 'id_20', text: 'dolorum deserunt quis', isCompleted: true },
]

export const USER_FIXTURES: Prisma.UserCreateInput[] = [
  { id: 1, email: 'user1@email.com' },
  { id: 2, email: 'user2@email.com' },
  { id: 3, email: 'user3@email.com' },
  { id: 4, email: 'user4@email.com' },
  { id: 5, email: 'user5@email.com' },
  { id: 6, email: 'user6@email.com' },
  { id: 7, email: 'user7@email.com' },
  { id: 8, email: 'user8@email.com' },
  { id: 9, email: 'user9@email.com' },
  { id: 10, email: 'user10@email.com' },
  { id: 11, email: 'user11@email.com' },
  { id: 12, email: 'user12@email.com' },
  { id: 13, email: 'user13@email.com' },
  { id: 14, email: 'user14@email.com' },
  { id: 15, email: 'user15@email.com' },
  { id: 16, email: 'user16@email.com' },
  { id: 17, email: 'user17@email.com' },
  { id: 18, email: 'user18@email.com' },
  { id: 19, email: 'user19@email.com' },
  { id: 20, email: 'user20@email.com' },
]

export const PROFILE_FIXTURES: Prisma.ProfileCreateInput[] = [
  { firstname: 'foo1', lastname: 'bar1' },
  { firstname: 'foo2', lastname: 'bar1' },
  { firstname: 'foo3', lastname: 'bar1' },
  { firstname: 'foo4', lastname: 'bar1' },
  { firstname: 'foo5', lastname: 'bar1' },
  { firstname: 'foo6', lastname: 'bar1' },
  { firstname: 'foo7', lastname: 'bar1' },
  { firstname: 'foo8', lastname: 'bar1' },
  { firstname: 'foo9', lastname: 'bar1' },
  { firstname: 'foo10', lastname: 'bar1' },
  { firstname: 'foo11', lastname: 'bar1' },
  { firstname: 'foo12', lastname: 'bar1' },
  { firstname: 'foo13', lastname: 'bar1' },
  { firstname: 'foo14', lastname: 'bar1' },
  { firstname: 'foo15', lastname: 'bar1' },
  { firstname: 'foo16', lastname: 'bar1' },
  { firstname: 'foo17', lastname: 'bar1' },
  { firstname: 'foo18', lastname: 'bar1' },
  { firstname: 'foo19', lastname: 'bar1' },
  { firstname: 'foo20', lastname: 'bar1' },
]
